@@ -1,5 +1,5 @@
 #TODO: Import all symbols and methods here
-from .solver import FIMPY
+from .solver import create_fim_solver
 
-__version__ = "1.2"
+__version__ = "1.2.1"
 __author__ = "Thomas Grandits"
\ No newline at end of file
