@@ -6,7 +6,6 @@ import numpy as np
 from itertools import permutations
 from abc import abstractmethod
 from .utils.tsitsiklis import norm_map
-#import pyximport; pyximport.install()
 from .fim_cutils import compute_point_elem_map_c, compute_neighborhood_map_c
 
 class FIMBase():
@@ -71,7 +70,6 @@ class FIMBase():
             self.point_elem_map = self.compute_point_elem_map()
 
         self.precision = precision
-        self.norm_map = norm_map
         self.dims = self.points.shape[-1]
         self.choose_update_alg()
 
@@ -107,7 +105,7 @@ class FIMBase():
         assert(metrics.shape[0] == self.nr_elems) #One constant metric for each element
         assert(metrics.ndim == 3)
         assert(metrics.shape[-1] == metrics.shape[-2] and metrics.shape[-1] == self.points.shape[-1])
-        assert(np.allclose(metrics - np.transpose(metrics, axes=(0, 2, 1)), 0.)) #Symmetric
+        assert(np.allclose(metrics - np.transpose(metrics, axes=(0, 2, 1)), 0., atol=1e-4)) #Symmetric
         assert(np.all(np.linalg.eigh(metrics)[0] > 1e-4)) #Positive definite
 
 
@@ -186,7 +184,7 @@ class FIMBase():
         ndarray (precision)
             An [..., N] array that holds :math:`||\\mathbf{x}_2 - \\mathbf{x}_1||_M`
         """
-        norm_f = self.norm_map[lib][D.shape[-1]][0]
+        norm_f = norm_map[lib][D.shape[-1]][0]
         a1 = x2 - x1
         return u1 + norm_f(D, a1, a1)
     
@@ -199,7 +197,7 @@ class FIMBase():
         in a broadcasted way.
         For more information on the type and shape of the parameters and return value, see :meth:`tsitsiklis_update_line`.
         """
-        norm_f = self.norm_map[lib][D.shape[-1]][0]
+        norm_f = norm_map[lib][D.shape[-1]][0]
 
         a1 = x3 - x1
         a2 = x3 - x2
@@ -220,7 +218,7 @@ class FIMBase():
         z2 = x2 - x3
         z1 = x1 - x2
 
-        norm_f, norm_sqr_f = self.norm_map[lib][D.shape[-1]]
+        norm_f, norm_sqr_f = norm_map[lib][D.shape[-1]]
 
         p11 = norm_sqr_f(D, x1=z1, x2=z1)
         p12 = norm_sqr_f(D, x1=z1, x2=z2)
@@ -251,7 +249,7 @@ class FIMBase():
     def tsitsiklis_update_tetra_quadr(self, D, k, z1, z2, lib=np):
         """Computes the quadratic equation for the tetrahedra update in :meth:`calculate_tet_update`.
         """
-        norm_f, norm_sqr_f = self.norm_map[lib][D.shape[-1]]
+        norm_f, norm_sqr_f = norm_map[lib][D.shape[-1]]
         p11 = norm_sqr_f(D, z1, z1)
         p12 = norm_sqr_f(D, z1, z2)
         p22 = norm_sqr_f(D, z2, z2)
@@ -294,7 +292,7 @@ class FIMBase():
         """
         xs = lib.stack([x1, x2, x3, x4], axis=-1)
         us = lib.stack([u1, u2, u3], axis=-1)
-        norm_f, norm_sqr_f = self.norm_map[lib][D.shape[-1]]
+        norm_f, norm_sqr_f = norm_map[lib][D.shape[-1]]
 
         y3 = x4 - x3
         y1 = x3 - x1
@@ -357,10 +355,7 @@ class FIMBase():
                                                   D, us_perm[..., 0], us_perm[..., 1], lib=lib)
 
         #Now we need to take the minimum result of old and all new
-        #if lib == np:
         lib.minimum.at(us_new, elems_perm[..., -1], us_result)
-        #elif lib == cp:
-        #    cpx.scatter_min(us_new, elems_perm[..., -1], us_result)
 
         return us_new
 
@@ -483,9 +478,10 @@ class FIMBase():
         """
         #Suppress warnings of the computations, since they should be handled internally
         with np.errstate(divide='ignore', invalid='ignore', over='ignore'):
-            assert(metrics is not None or self.metrics is not None) #Metrics were neither in the constructor, nor here given
+            #TODO: Maybe use identity in this case?
+            assert metrics is not None or self.metrics is not None, f"Metrics (D) need to be provided in comp_fim, or at construction in __init__"
             if metrics is not None:
                 self.check_metrics_argument(metrics)
                 metrics = np.linalg.inv(metrics).astype(self.precision) #The inverse metric is used in the FIM algorithm
 
-            return self._comp_fim(x0, x0_vals, metrics)
\ No newline at end of file
+            return self._comp_fim(x0, x0_vals, metrics, max_iterations=max_iterations)
